/***************************************************************************
 *   Copyright (C) 2003 by Hideki Ikemoto                                  *
 *   ikemo@wakaba.jp                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef BOARDTEST_H
#define BOARDTEST_H

#include <cppunit/extensions/HelperMacros.h>
#include <../board.h>

/**
@author Hideki Ikemoto
*/
class BoardTest : public CppUnit::TestFixture {
    CPPUNIT_TEST_SUITE( BoardTest );
    CPPUNIT_TEST( testID );
    CPPUNIT_TEST( testStaticName );
    CPPUNIT_TEST( testReplace );
    CPPUNIT_TEST_SUITE_END();

public:
    void setUp();
    void tearDown();

    void testID();
    void testStaticName();
    void testReplace();
};

#endif
